==> haskell-pgp-wordlist-0.1.0.2-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pgp-wordlist
version: 0.1.0.2
id: pgp-wordlist-0.1.0.2-FHedwRghjKOJjk8O91BBkz
key: pgp-wordlist-0.1.0.2-FHedwRghjKOJjk8O91BBkz
license: BSD-3-Clause
copyright: David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer: David Luposchainsky <dluposchainsky(λ)gmail.com>
author: David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage: https://github.com/quchen/pgp-wordlist
synopsis: Translate between binary data and a human-readable
          collection of words.
description:
    Translate between binary data and a human-readable
    collection of words.
    .
    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.
    .
    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.
    .
    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.
category: Data, Serialization
abi: 917c4cd98777cccaa0399543350db323
exposed: True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words
import-dirs: /usr/lib/ghc-8.4.3/site-local/pgp-wordlist-0.1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pgp-wordlist-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pgp-wordlist-0.1.0.2
hs-libraries: HSpgp-wordlist-0.1.0.2-FHedwRghjKOJjk8O91BBkz
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock
haddock-html: /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pgp-wordlist-0.1.0.2-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pgp-wordlist
version: 0.1.0.2
id: pgp-wordlist-0.1.0.2-HjZCULYhXk05wJogxbtkEp
key: pgp-wordlist-0.1.0.2-HjZCULYhXk05wJogxbtkEp
license: BSD-3-Clause
copyright: David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer: David Luposchainsky <dluposchainsky(λ)gmail.com>
author: David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage: https://github.com/quchen/pgp-wordlist
synopsis: Translate between binary data and a human-readable
          collection of words.
description:
    Translate between binary data and a human-readable
    collection of words.
    .
    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.
    .
    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.
    .
    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.
category: Data, Serialization
abi: 41c79223be3e4bf645aef298034c4632
exposed: True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words
import-dirs: /usr/lib/ghc-8.4.3/site-local/pgp-wordlist-0.1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pgp-wordlist-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pgp-wordlist-0.1.0.2
hs-libraries: HSpgp-wordlist-0.1.0.2-HjZCULYhXk05wJogxbtkEp
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock
haddock-html: /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
